# Changelog

## 1.6.0 (2025-12-17)

Full Changelog: [v1.5.2...v1.6.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.5.2...v1.6.0)

### Features

* **api:** api update ([450e6a6](https://github.com/with-ours/ingest-sdk-python/commit/450e6a6088abd0be782eda40cdc3f8da7747fff0))

## 1.5.2 (2025-12-17)

Full Changelog: [v1.5.1...v1.5.2](https://github.com/with-ours/ingest-sdk-python/compare/v1.5.1...v1.5.2)

### Chores

* speedup initial import ([ae14513](https://github.com/with-ours/ingest-sdk-python/commit/ae14513fb6fb88118ac0168fb4a69dc04f2d9c36))

## 1.5.1 (2025-12-16)

Full Changelog: [v1.5.0...v1.5.1](https://github.com/with-ours/ingest-sdk-python/compare/v1.5.0...v1.5.1)

### Chores

* **internal:** add missing files argument to base client ([25e312c](https://github.com/with-ours/ingest-sdk-python/commit/25e312c7d8bd11cc47d91370b06f75ae40b3f3c7))

## 1.5.0 (2025-12-11)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.4.0...v1.5.0)

### Features

* **api:** api update ([91aac63](https://github.com/with-ours/ingest-sdk-python/commit/91aac633d408c8e69a066f8d8655d6a49e2348e6))

## 1.4.0 (2025-12-11)

Full Changelog: [v1.3.0...v1.4.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.3.0...v1.4.0)

### Features

* **api:** api update ([550fe42](https://github.com/with-ours/ingest-sdk-python/commit/550fe4268809b1c8317a88527a798b85bf28a1c6))

## 1.3.0 (2025-12-10)

Full Changelog: [v1.2.3...v1.3.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.2.3...v1.3.0)

### Features

* **api:** api update ([9957d63](https://github.com/with-ours/ingest-sdk-python/commit/9957d633b4d913aeb42498e57c305b3b817a355e))

## 1.2.3 (2025-12-09)

Full Changelog: [v1.2.2...v1.2.3](https://github.com/with-ours/ingest-sdk-python/compare/v1.2.2...v1.2.3)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([56b7762](https://github.com/with-ours/ingest-sdk-python/commit/56b7762f847d1e18c47de1c5751f4b5dd3af48ac))


### Chores

* add missing docstrings ([c69a391](https://github.com/with-ours/ingest-sdk-python/commit/c69a39178bb856462f20d19c904c604b83365bf0))

## 1.2.2 (2025-12-03)

Full Changelog: [v1.2.1...v1.2.2](https://github.com/with-ours/ingest-sdk-python/compare/v1.2.1...v1.2.2)

### Chores

* update lockfile ([06565c9](https://github.com/with-ours/ingest-sdk-python/commit/06565c969d21d8d2bca00303f4411bb376fd7214))

## 1.2.1 (2025-11-28)

Full Changelog: [v1.2.0...v1.2.1](https://github.com/with-ours/ingest-sdk-python/compare/v1.2.0...v1.2.1)

### Bug Fixes

* ensure streams are always closed ([0d6b6f0](https://github.com/with-ours/ingest-sdk-python/commit/0d6b6f0f4ad99f46c9815b136f828f210295bc88))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([8decd50](https://github.com/with-ours/ingest-sdk-python/commit/8decd50690d7ebc355c7fc7e7b1adbbad2ef7549))

## 1.2.0 (2025-11-22)

Full Changelog: [v1.1.0...v1.2.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.1.0...v1.2.0)

### Features

* **api:** api update ([056fb31](https://github.com/with-ours/ingest-sdk-python/commit/056fb315770479159e447bc14f3514343936fc5e))
* **api:** api update ([1d5b0b9](https://github.com/with-ours/ingest-sdk-python/commit/1d5b0b95d3524f8c213d9387947a7d44c8584955))


### Chores

* add Python 3.14 classifier and testing ([88dcfd9](https://github.com/with-ours/ingest-sdk-python/commit/88dcfd9a234ee59926b2b0127b4d3d0b9e3d6be8))

## 1.1.0 (2025-11-19)

Full Changelog: [v1.0.1...v1.1.0](https://github.com/with-ours/ingest-sdk-python/compare/v1.0.1...v1.1.0)

### Features

* **api:** manual updates ([308f0b9](https://github.com/with-ours/ingest-sdk-python/commit/308f0b98f72db1d25da612a267012a29484bfc97))


### Bug Fixes

* compat with Python 3.14 ([cd383a5](https://github.com/with-ours/ingest-sdk-python/commit/cd383a547755f9f4d2bead67e0e550182acdd058))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([88a2708](https://github.com/with-ours/ingest-sdk-python/commit/88a2708fdf7677fd6f247801f1010dc5beaba4af))


### Chores

* **package:** drop Python 3.8 support ([2efe742](https://github.com/with-ours/ingest-sdk-python/commit/2efe7425d8e2ede324289b0355586f0b8608de6d))

## 1.0.1 (2025-11-05)

Full Changelog: [v0.0.1...v1.0.1](https://github.com/with-ours/ingest-sdk-python/compare/v0.0.1...v1.0.1)

### Features

* **api:** manual updates ([bb8c874](https://github.com/with-ours/ingest-sdk-python/commit/bb8c8740c8db117eea1397087a1c6caf84dc9f4f))
* **api:** manual updates ([2fb7a18](https://github.com/with-ours/ingest-sdk-python/commit/2fb7a189d3d85379b026eda316d0941895bf523e))


### Chores

* configure new SDK language ([57f5f26](https://github.com/with-ours/ingest-sdk-python/commit/57f5f26caf7d784f70bf2aa313030c64c4404e5a))
* **internal:** grammar fix (it's -&gt; its) ([fcb2e5a](https://github.com/with-ours/ingest-sdk-python/commit/fcb2e5a28fc12b5d828409f474936d5300e5abf4))
* update SDK settings ([23d204c](https://github.com/with-ours/ingest-sdk-python/commit/23d204c23a68376a0340d1fa6dc160477fe9dd11))
* update SDK settings ([f53800e](https://github.com/with-ours/ingest-sdk-python/commit/f53800e088f0068679c32bd7656dc75e74b9a727))
